/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.health.connect.datatypes;

import android.health.connect.datatypes.units.Energy;
import android.health.connect.HealthConnectManager;

/**
 * Total energy burned by the user in {@link android.health.connect.datatypes.units.Energy Energy}, including active & basal energy burned (BMR).
 * Each record represents the total kilocalories burned over a time interval.
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class TotalCaloriesBurnedRecord extends android.health.connect.datatypes.IntervalRecord {

TotalCaloriesBurnedRecord() { throw new RuntimeException("Stub!"); }

/**
 * @return energy burned during this activity in {@link android.health.connect.datatypes.units.Energy Energy} unit.

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.units.Energy getEnergy() { throw new RuntimeException("Stub!"); }

/**
 * Indicates whether some other object is "equal to" this one.
 *
 * @param object the reference object with which to compare.
 * This value cannot be {@code null}.
 * @return {@code true} if this object is the same as the object argument; {@code false}
 *     otherwise.
 */

public boolean equals(@android.annotation.NonNull java.lang.Object object) { throw new RuntimeException("Stub!"); }

/** Returns a hash code value for the object. */

public int hashCode() { throw new RuntimeException("Stub!"); }

/**
 * Metric identifier to get total energy from total calories burned using aggregate APIs in
 * {@link android.health.connect.HealthConnectManager HealthConnectManager}
 */

@android.annotation.NonNull public static final android.health.connect.datatypes.AggregationType<android.health.connect.datatypes.units.Energy> ENERGY_TOTAL;
static { ENERGY_TOTAL = null; }
/** Builder class for {@link android.health.connect.datatypes.TotalCaloriesBurnedRecord TotalCaloriesBurnedRecord} */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class Builder {

/**
 * @param metadata Metadata to be associated with the record. See {@link android.health.connect.datatypes.Metadata Metadata}.
 * This value cannot be {@code null}.
 * @param startTime Start time of this activity
 * This value cannot be {@code null}.
 * @param endTime End time of this activity
 * This value cannot be {@code null}.
 * @param energy Energy burned during this activity in {@link android.health.connect.datatypes.units.Energy Energy} unit. Required field.
 *     Valid range: 0-1000000 kcal.

 * This value cannot be {@code null}.
 */

public Builder(@android.annotation.NonNull android.health.connect.datatypes.Metadata metadata, @android.annotation.NonNull java.time.Instant startTime, @android.annotation.NonNull java.time.Instant endTime, @android.annotation.NonNull android.health.connect.datatypes.units.Energy energy) { throw new RuntimeException("Stub!"); }

/**
 * Sets the zone offset of the user when the activity started
 * @param startZoneOffset This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.TotalCaloriesBurnedRecord.Builder setStartZoneOffset(@android.annotation.NonNull java.time.ZoneOffset startZoneOffset) { throw new RuntimeException("Stub!"); }

/**
 * Sets the zone offset of the user when the activity ended
 * @param endZoneOffset This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.TotalCaloriesBurnedRecord.Builder setEndZoneOffset(@android.annotation.NonNull java.time.ZoneOffset endZoneOffset) { throw new RuntimeException("Stub!"); }

/**
 * Sets the start zone offset of this record to system default.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.TotalCaloriesBurnedRecord.Builder clearStartZoneOffset() { throw new RuntimeException("Stub!"); }

/**
 * Sets the start zone offset of this record to system default.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.TotalCaloriesBurnedRecord.Builder clearEndZoneOffset() { throw new RuntimeException("Stub!"); }

/**
 * @return Object of {@link android.health.connect.datatypes.TotalCaloriesBurnedRecord TotalCaloriesBurnedRecord}

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.TotalCaloriesBurnedRecord build() { throw new RuntimeException("Stub!"); }
}

}

